==> phoenix_widgets-1.11.1.tar.gz: lib/phoenix_banner.dart <==
import 'dart:async';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

enum GestureEvent { onSwipe, onTap }

enum IndicatorPosition { top, bottom }

class PhoenixBanner extends StatefulWidget {
  const PhoenixBanner({
    Key? key,
    required this.listSlider,
    this.carouselDurationMs = 3000,
    this.onEvent,
    this.activeColour,
    this.inActiveColour,
    this.bannerHeight = 170.0,
    this.viewportFraction = 0.9,
    this.fit = BoxFit.cover,
    this.indicatorPosition = IndicatorPosition.bottom,
  }) : super(key: key);
  final List<String> listSlider;
  final int? carouselDurationMs;
  final void Function(GestureEvent event, int index)? onEvent;
  final Color? activeColour;
  final Color? inActiveColour;
  final double? bannerHeight;
  final double? viewportFraction;
  final BoxFit? fit;
  final IndicatorPosition? indicatorPosition;

  @override
  _PhoenixBannerState createState() => _PhoenixBannerState();
}

class _PhoenixBannerState extends State<PhoenixBanner> {
  late PageController _pageController;
  var _currentPage = 0;
  late Timer _timer;

  @override
  void initState() {
    super.initState();
    _timer = _setupTimer;
    _pageController =
        PageController(viewportFraction: widget.viewportFraction ?? 0.9);
  }

  void _onEvent(GestureEvent event, int index) {
    if (widget.onEvent != null) {
      widget.onEvent!(event, index);
    }
  }

  Widget renderIndicator() {
    return Row(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        // generate indicator from total page
        for (int i = 0; i < widget.listSlider.length; i++)
          _IndicatorSlider(
            isActive: i == _currentPage,
            activeColour: widget.activeColour ?? Colors.white,
            inActiveColour:
                widget.inActiveColour ?? Colors.black.withOpacity(0.25),
          ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        if (widget.indicatorPosition == IndicatorPosition.top) ...[
          const SizedBox(height: 16),
          renderIndicator(),
        ],
        SizedBox(
          height: widget.bannerHeight,
          child: GestureDetector(
            onHorizontalDragEnd: (dragEndDetails) async {
              if ((dragEndDetails.primaryVelocity ?? 0) < 0) {
                await _pageController.nextPage(
                  duration: const Duration(milliseconds: 300),
                  curve: Curves.ease,
                );
              } else if ((dragEndDetails.primaryVelocity ?? 0) > 0) {
                await _pageController.previousPage(
                  duration: const Duration(milliseconds: 300),
                  curve: Curves.ease,
                );
              }
              _onEvent(GestureEvent.onSwipe, _currentPage);
            },
            child: _carousel(),
          ),
        ),
        if (widget.indicatorPosition == IndicatorPosition.bottom) ...[
          const SizedBox(height: 16),
          renderIndicator(),
        ],
      ],
    );
  }

  @override
  void dispose() {
    _pageController.dispose();
    _timer.cancel();
    super.dispose();
  }

  PageView _carousel() => PageView.builder(
        controller: _pageController,
        itemCount: widget.listSlider.length,
        physics: const NeverScrollableScrollPhysics(),
        onPageChanged: (int page) {
          setState(() {
            _currentPage = page;
          });
        },
        itemBuilder: (_, index) => _carouselBuilder(index),
      );

  Widget _carouselBuilder(int index) => Center(
        child: Material(
          color: Colors.transparent,
          child: InkWell(
            onTap: () async {
              _timer.cancel();

              _onEvent(GestureEvent.onTap, index);

              _timer = _setupTimer;
            },
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8),
              child: Container(
                clipBehavior: Clip.antiAlias,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(4),
                ),
                child: CachedNetworkImage(
                  imageUrl: widget.listSlider[index],
                  fit: widget.fit,
                  height: widget.bannerHeight,
                  placeholder: (context, text) {
                    return PhoenixShimmer.rectangular(
                      height: widget.bannerHeight!,
                      baseColor: Colors.white.withOpacity(0.5),
                    );
                  },
                ),
              ),
            ),
          ),
        ),
      );

  Timer get _setupTimer => Timer.periodic(
        Duration(milliseconds: widget.carouselDurationMs ?? 3000),
        (timer) {
          if (_currentPage != widget.listSlider.length - 1) {
            setState(() {
              _currentPage++;
              _pageController.animateToPage(
                _currentPage,
                duration: const Duration(milliseconds: 1200),
                curve: Curves.ease,
              );
            });
          } else {
            //reset if _currentPage == _totalPage
            setState(() {
              _currentPage = 0;
              _pageController.jumpToPage(
                _currentPage,
              );
            });
          }
        },
      );
}

class _IndicatorSlider extends StatelessWidget {
  const _IndicatorSlider({
    Key? key,
    required this.isActive,
    required this.activeColour,
    required this.inActiveColour,
  }) : super(key: key);

  final bool isActive;
  final Color activeColour;
  final Color inActiveColour;

  @override
  Widget build(BuildContext context) {
    return AnimatedContainer(
      duration: const Duration(milliseconds: 300),
      margin: const EdgeInsets.symmetric(horizontal: 2),
      width: 8,
      height: 8,
      decoration: BoxDecoration(
        color: isActive ? activeColour : inActiveColour,
        shape: BoxShape.circle,
      ),
    );
  }
}

==> phoenix_widgets-1.17.4.tar.gz: lib/phoenix_banner.dart <==
import 'dart:async';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

enum GestureEvent { onSwipe, onTap }

enum IndicatorPosition { top, bottom }

class PhoenixBanner extends StatefulWidget {
  const PhoenixBanner({
    Key? key,
    required this.listSlider,
    this.carouselDurationMs = 3000,
    this.onEvent,
    this.activeColour,
    this.inActiveColour,
    this.bannerHeight = 170.0,
    this.viewportFraction = 0.9,
    this.fit = BoxFit.cover,
    this.indicatorPosition = IndicatorPosition.bottom,
  }) : super(key: key);
  final List<String> listSlider;
  final int? carouselDurationMs;
  final void Function(GestureEvent event, int index)? onEvent;
  final Color? activeColour;
  final Color? inActiveColour;
  final double? bannerHeight;
  final double? viewportFraction;
  final BoxFit? fit;
  final IndicatorPosition? indicatorPosition;

  @override
  State<PhoenixBanner> createState() => _PhoenixBannerState();
}

class _PhoenixBannerState extends State<PhoenixBanner> {
  late PageController _pageController;
  var _currentPage = 0;
  late Timer _timer;

  @override
  void initState() {
    super.initState();
    _timer = _setupTimer;
    _pageController =
        PageController(viewportFraction: widget.viewportFraction ?? 0.9);
  }

  void _onEvent(GestureEvent event, int index) {
    if (widget.onEvent != null) {
      widget.onEvent!(event, index);
    }
  }

  Widget renderIndicator() {
    return Row(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        // generate indicator from total page
        for (int i = 0; i < widget.listSlider.length; i++)
          _IndicatorSlider(
            isActive: i == _currentPage,
            activeColour: widget.activeColour ?? Colors.white,
            inActiveColour:
                widget.inActiveColour ?? Colors.black.withOpacity(0.25),
          ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        if (widget.indicatorPosition == IndicatorPosition.top) ...[
          const SizedBox(height: 16),
          renderIndicator(),
        ],
        SizedBox(
          height: widget.bannerHeight,
          child: GestureDetector(
            onHorizontalDragEnd: (dragEndDetails) async {
              if ((dragEndDetails.primaryVelocity ?? 0) < 0) {
                await _pageController.nextPage(
                  duration: const Duration(milliseconds: 300),
                  curve: Curves.ease,
                );
              } else if ((dragEndDetails.primaryVelocity ?? 0) > 0) {
                await _pageController.previousPage(
                  duration: const Duration(milliseconds: 300),
                  curve: Curves.ease,
                );
              }
              _onEvent(GestureEvent.onSwipe, _currentPage);
            },
            child: _carousel(),
          ),
        ),
        if (widget.indicatorPosition == IndicatorPosition.bottom) ...[
          const SizedBox(height: 16),
          renderIndicator(),
        ],
      ],
    );
  }

  @override
  void dispose() {
    _pageController.dispose();
    _timer.cancel();
    super.dispose();
  }

  PageView _carousel() => PageView.builder(
        controller: _pageController,
        itemCount: widget.listSlider.length,
        physics: const NeverScrollableScrollPhysics(),
        onPageChanged: (int page) {
          setState(() {
            _currentPage = page;
          });
        },
        itemBuilder: (_, index) => _carouselBuilder(index),
      );

  Widget _carouselBuilder(int index) => Center(
        child: Material(
          color: Colors.transparent,
          child: InkWell(
            onTap: () async {
              _timer.cancel();

              _onEvent(GestureEvent.onTap, index);

              _timer = _setupTimer;
            },
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8),
              child: Container(
                clipBehavior: Clip.antiAlias,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(4),
                ),
                child: CachedNetworkImage(
                  imageUrl: widget.listSlider[index],
                  fit: widget.fit,
                  height: widget.bannerHeight,
                  placeholder: (context, text) {
                    return PhoenixShimmer.rectangular(
                      height: widget.bannerHeight!,
                      baseColor: Colors.white.withOpacity(0.5),
                    );
                  },
                ),
              ),
            ),
          ),
        ),
      );

  Timer get _setupTimer => Timer.periodic(
        Duration(milliseconds: widget.carouselDurationMs ?? 3000),
        (timer) {
          if (_currentPage != widget.listSlider.length - 1) {
            setState(() {
              _currentPage++;
              _pageController.animateToPage(
                _currentPage,
                duration: const Duration(milliseconds: 1200),
                curve: Curves.ease,
              );
            });
          } else {
            //reset if _currentPage == _totalPage
            setState(() {
              _currentPage = 0;
              _pageController.jumpToPage(
                _currentPage,
              );
            });
          }
        },
      );
}

class _IndicatorSlider extends StatelessWidget {
  const _IndicatorSlider({
    Key? key,
    required this.isActive,
    required this.activeColour,
    required this.inActiveColour,
  }) : super(key: key);

  final bool isActive;
  final Color activeColour;
  final Color inActiveColour;

  @override
  Widget build(BuildContext context) {
    return AnimatedContainer(
      duration: const Duration(milliseconds: 300),
      margin: const EdgeInsets.symmetric(horizontal: 2),
      width: 8,
      height: 8,
      decoration: BoxDecoration(
        color: isActive ? activeColour : inActiveColour,
        shape: BoxShape.circle,
      ),
    );
  }
}
